summaryrefslogtreecommitdiffstats
path: root/korn/boxcontaineritem.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:49:30 -0600
commita9bde819f2b421dcc44741156e75eca4bb5fb4f4 (patch)
treed087071b1e8fcf79698938efec19f8e48bab0799 /korn/boxcontaineritem.h
parent5c4a80ead2b1fe57dc6a8c29d0368792344cd61e (diff)
downloadtdepim-a9bde819f2b421dcc44741156e75eca4bb5fb4f4.tar.gz
tdepim-a9bde819f2b421dcc44741156e75eca4bb5fb4f4.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'korn/boxcontaineritem.h')
-rw-r--r--korn/boxcontaineritem.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korn/boxcontaineritem.h b/korn/boxcontaineritem.h
index e12c400f..f903feb8 100644
--- a/korn/boxcontaineritem.h
+++ b/korn/boxcontaineritem.h
@@ -27,7 +27,7 @@ class KornMailSubject;
class KActionCollection;
class KConfig;
class KPopupMenu;
-class KProcess;
+class TDEProcess;
class TQColor;
class TQLabel;
@@ -213,10 +213,10 @@ signals:
private slots:
/**
* This slot is called when a KProcess-instance needs to be deleted:)
* @param proc The instance of the instance which must be deleted.
*/
- void processExited( KProcess* proc );
+ void processExited( TDEProcess* proc );
protected:
//This settings are stored here because every implementation needs them.
@@ -213,10 +213,10 @@ signals:
private slots:
/**
- * This slot is called when a KProcess-instance needs to be deleted:)
+ * This slot is called when a TDEProcess-instance needs to be deleted:)
* @param proc The instance of the instance which must be deleted.
*/